@@ -155,24 +155,24 @@ def _extract_v4l_path_parts(v4l_path):
     usb_str = match.group("usb_id")
     chn_id = int(match.group("chn_id"))
 
+    parts = {}
+
     # Parse PCI: domain:bus:slot.func
-    domain, bus, slot_func = pci_str.split(":")
-    slot, func = slot_func.split(".")
-    pci_tuple = (int(domain, 16), int(bus, 16), int(slot, 16), int(func))
+    if pci_str:
+        domain, bus, slot_func = pci_str.split(":")
+        slot, func = slot_func.split(".")
+        pci_tuple = (int(domain, 16), int(bus, 16), int(slot, 16), int(func))
+        parts["pci"] = pci_tuple
 
     # Parse USB: split on : and .
-    usb_parts = []
-    for part in usb_str.replace(".", ":").split(":"):
-        usb_parts.append(int(part))
-    usb_tuple = tuple(usb_parts)
-
-    parts = {
-        "pci": pci_tuple,
-        "usb": usb_tuple,
-        "chn": chn_id,
-        "str": ""
-    }
+    if usb_str:
+        usb_parts = []
+        for part in usb_str.replace(".", ":").split(":"):
+            usb_parts.append(int(part))
+        usb_tuple = tuple(usb_parts)
+        parts["usb"] = usb_tuple
 
+    parts["chn"] = chn_id
     parts["str"] = _repack_v4l_path_parts(parts)
     return parts
 
